import { useState, useLayoutEffect } from "react";
import debounce from "lodash.debounce";
const defaultBreakpoints = {
    sm: 640,
    md: 768,
    lg: 1024,
    xl: 1280,
    "2xl": 1536,
};
// Returns an object so that you can safely check multiple breakpoints directly (from lowest to highest)
// the same way you would do in Tailwind
export function useResponsiveBreakpoints(breakpoints = defaultBreakpoints) {
    const [currentBreakpoints, setCurrentBreakpoints] = useState(null);
    useLayoutEffect(() => {
        const updateSize = () => {
            const newBreakpoints = Object.assign({}, (currentBreakpoints || {
                sm: false,
                md: false,
                lg: false,
                xl: false,
                "2xl": false,
            }));
            ["sm", "md", "lg", "xl", "2xl"].forEach((breakpoint) => {
                newBreakpoints[breakpoint] =
                    window.innerWidth > breakpoints[breakpoint];
            });
            setCurrentBreakpoints(newBreakpoints);
        };
        window.addEventListener("resize", debounce(updateSize, 30));
        return () => window.removeEventListener("resize", updateSize);
    });
    return currentBreakpoints;
}
//# sourceMappingURL=useResponsiveBreakpoints.js.map