import React, { useMemo } from "react";
import { useTranslation } from "react-i18next";
import { CaretDoubleLeft as CaretDoubleLeftIcon } from "@phosphor-icons/react";
import { useRootElement } from "../context";
import * as styles from "./styles";
export function Header({ title }) {
    const { t } = useTranslation("localContent");
    const { isExpanded, onToggleIsExpanded } = useRootElement();
    const displayTitle = useMemo(() => (typeof title === "string" ? title : t("scoresMenu.header.title")), [title]);
    const handleOnArrowClick = (event) => {
        event.stopPropagation();
        onToggleIsExpanded();
    };
    return (React.createElement("div", { className: styles.container, "data-testid": "scores-menu-header" },
        React.createElement("h2", { className: styles.title, "aria-label": displayTitle, "data-testid": "scores-menu-header-title" }, title === false ? "" : displayTitle),
        React.createElement("button", { type: "button", onClick: handleOnArrowClick, "aria-label": t("scoresMenu.header.toggle.ariaLabel", {
                context: isExpanded ? "close" : "open",
            }), "aria-pressed": isExpanded, "data-testid": "scores-menu-header-toggle" },
            React.createElement(CaretDoubleLeftIcon, { className: styles.icon, "aria-hidden": "true", focusable: "false", "data-testid": "scores-menu-header-toggle-icon" }))));
}
//# sourceMappingURL=index.js.map