import React, { useContext, useMemo } from "react";
import { useTracking } from "@local-logic/core/tracking";
import useEffectOnce from "~/hooks/useEffectOnce";
import { useStateManagerContext } from "~/context/stateManager";
import { transformScoresMenuData } from "./utils";
import { TrackingPipelineEvents, AnalyticsEvents, } from "./types";
const LocalContentContext = React.createContext({});
const useLocalContent = () => useContext(LocalContentContext);
const LocalContentProvider = ({ children, }) => {
    var _a, _b;
    const { sdkState } = useStateManagerContext();
    const tracking = useTracking();
    useEffectOnce(() => {
        tracking.postEvent({
            eventType: TrackingPipelineEvents.SDK_VIEWED,
        });
        tracking.trackAnalyticsEvent({
            eventName: AnalyticsEvents.SDK_VIEWED,
        });
    });
    const sortedScoresMenu = useMemo(() => { var _a; return transformScoresMenuData((_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.scoresMenu); }, [(_b = (_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.scoresMenu) === null || _b === void 0 ? void 0 : _b.categories]);
    const isLoading = useMemo(() => false, []);
    const contextValue = useMemo(() => {
        var _a, _b, _c, _d, _e, _f, _g;
        return ({
            isLoading,
            location: {
                lat: ((_a = sdkState.options) === null || _a === void 0 ? void 0 : _a.lat) || 0,
                lng: ((_b = sdkState.options) === null || _b === void 0 ? void 0 : _b.lng) || 0,
            },
            map: {
                mapProvider: (_c = sdkState.options) === null || _c === void 0 ? void 0 : _c.mapProvider,
                zoom: (_d = sdkState.options) === null || _d === void 0 ? void 0 : _d.zoom,
                pitch: (_e = sdkState.options) === null || _e === void 0 ? void 0 : _e.pitch,
                bearing: (_f = sdkState.options) === null || _f === void 0 ? void 0 : _f.bearing,
                cooperativeGestures: (_g = sdkState.options) === null || _g === void 0 ? void 0 : _g.cooperativeGestures,
            },
            scoresMenu: sortedScoresMenu,
        });
    }, [isLoading, sdkState.options]);
    return (React.createElement(LocalContentContext.Provider, { value: contextValue }, children));
};
export { useLocalContent, LocalContentProvider };
//# sourceMappingURL=context.js.map